//  Copyright 2019 Kakao Corp.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import Foundation

///:nodoc:
class ParamUserDefaults {
    static let paramsInfoKey = "com.kakao.sdk.sample.apiParamsInfo"
    
    static func saveCodable<T: Codable>(data:T?) {
        if let encoded = try? JSONEncoder().encode(data) {
            UserDefaults.standard.set(encoded, forKey:paramsInfoKey)
            UserDefaults.standard.synchronize()
        }
    }
    
    static func loadCodable<T: Codable>() -> T? {
        if let data = UserDefaults.standard.data(forKey: paramsInfoKey) {
            return try? JSONDecoder().decode(T.self, from:data)
        }
        return nil
    }
    
    static func delete(_ key: String) {
        UserDefaults.standard.removeObject(forKey: paramsInfoKey)
    }
}
